from datetime import date, datetime

from pci_gateway.clients import AuthorizeClient


class TestAuthorizeClient:
    """Tests for AuthorizeClient."""

    def test_payment_url(self):
        client = AuthorizeClient("https://gateway.umich.edu/", "OrderType", "testkey")
        payment_url = client.get_payment_url(
            ref_id="REF001",
            amount=3456,
            redirect_url="https://redirect.url/",
            cancel_url="https://cancel.url/",
            timestamp=datetime.fromtimestamp(1234567890.12345),
        )
        assert payment_url == (
            "https://gateway.umich.edu/authApi/authorize/payment/?"
            "order_type=OrderType&"
            "refId=REF001&"
            "amount=34.56&"
            "redirect_url=https%3A%2F%2Fredirect.url%2F&"
            "cancel_url=https%3A%2F%2Fcancel.url%2F&"
            "timestamp=1234567890&"
            "order_hash="
            "12b3dc38aa59a66c5f5ba282abb355cad6a68eea359c78e07c315416b203ae31"
        )

    def test_subscription_url(self):
        client = AuthorizeClient("https://gateway.umich.edu/", "OrderType", "testkey")
        subscription_url = client.get_subscription_url(
            ref_id="REF001",
            length=12,
            unit="months",
            total_occurances=1,
            amount=1234,
            redirect_url="https://redirect.url/",
            merchant_customer_id="MCID54321",
            start_date=date(2024, 1, 1),
            invoice_number="IN8765",
            name="Subscription name",
            trial_occurances=1,
            trial_amount=100,
            customer_address_id=888,
            timestamp=datetime.fromtimestamp(1234567890.12345),
        )
        assert subscription_url == (
            "https://gateway.umich.edu/authApi/subscription/create/?"
            "order_type=OrderType&"
            "refId=REF001&"
            "length=12&"
            "unit=months&"
            "start_date=2024-01-01&"
            "total_occurances=1&"
            "amount=12.34&"
            "redirect_url=https%3A%2F%2Fredirect.url%2F&"
            "merchant_customerId=MCID54321&"
            "timestamp=1234567890&"
            "invoice_number=IN8765&"
            "name=Subscription+name&"
            "trial_occurances=1&"
            "trial_amount=1.00&"
            "customer_addressId=888&"
            "order_hash="
            "5da1d88ff60a5181490926f7fb2dce672480d87a700a08fee10cdb69c28ae784"
        )
