from datetime import datetime

import pytest

from pci_gateway import utils


class TestGetAmountString:
    """Tests for get_amount_string."""

    @pytest.mark.parametrize(
        ("cents", "amount"),
        [
            (0, "0.00"),
            (1, "0.01"),
            (12, "0.12"),
            (123, "1.23"),
            (1234, "12.34"),
            (999999999999999, "9999999999999.99"),
        ],
    )
    def test_amount_string(self, cents, amount):
        assert utils.get_amount_string(cents) == amount

    def test_negative_value_raises_exception(self):
        with pytest.raises(ValueError):
            utils.get_amount_string(-1)

    def test_exceeding_digit_limit(self):
        with pytest.raises(ValueError):
            utils.get_amount_string(1000000000000000)


def test_get_timestamp():
    """Test for get_timestamp."""
    timestamp = 1234567890.12345
    dt = datetime.fromtimestamp(timestamp)
    assert utils.get_timestamp(dt) == 1234567890


def test_concatenate_params():
    """Test for concatinate_params."""
    params = {
        "timestamp": ["1234567890"],
        "cancel_url": ["https://cancel.url/"],
        "redirect_url": ["https://redirect.url/"],
        "refId": ["REF"],
        "amount": ["12.34"],
        "order_type": ["OrderType"],
    }
    assert utils.concatenate_params(params) == (
        "OrderTypeREF12.34https://redirect.url/https://cancel.url/1234567890"
    )


def test_calculate_hash():
    """Test for caculate_hash."""
    assert (
        utils.calculate_hash("message", "key")
        == "48fde309cc9b11d312cf6ef60e00d4274456687643fb56ed4111c152634086e0"
    )
